==> igniteui-react-16.16.2.tgz: package/esm5/lib/DockingIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { DockingIndicatorPosition_$type } from "./DockingIndicatorPosition";
/**
 * @hidden
 */
var DockingIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DockingIndicator, _super);
    function DockingIndicator() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = new WCNativeHelper();
        _this.e = null;
        return _this;
    }
    Object.defineProperty(DockingIndicator.prototype, "c", {
        get: function () {
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockingIndicator.prototype, "nativeElement", {
        get: function () {
            return this.e;
        },
        set: function (a) {
            this.e = a;
            this.b.d = this.e;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockingIndicator.prototype, "a", {
        get: function () {
            var ret_ = this.c.c("position");
            ret_ = enumGetBox(DockingIndicatorPosition_$type, EnumUtil.getEnumValue(DockingIndicatorPosition_$type, EnumUtil.parse(DockingIndicatorPosition_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(DockingIndicatorPosition_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(DockingIndicatorPosition_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.c.i("position", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockingIndicator.prototype, "d", {
        get: function () {
            var ret_ = this.c.c("isRoot");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.i("isRoot", value_);
        },
        enumerable: false,
        configurable: true
    });
    DockingIndicator.$t = markType(DockingIndicator, 'DockingIndicator');
    return DockingIndicator;
}(Base));
export { DockingIndicator };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/DockingIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { DockingIndicatorPosition_$type } from "./DockingIndicatorPosition";
/**
 * @hidden
 */
var DockingIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DockingIndicator, _super);
    function DockingIndicator() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = new WCNativeHelper();
        _this.e = null;
        return _this;
    }
    Object.defineProperty(DockingIndicator.prototype, "c", {
        get: function () {
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockingIndicator.prototype, "nativeElement", {
        get: function () {
            return this.e;
        },
        set: function (a) {
            this.e = a;
            this.b.o = this.e;
        },
        enumerable: false,
        configurable: true
    });
    DockingIndicator.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(DockingIndicator.prototype, "a", {
        get: function () {
            var ret_ = this.c.n("position");
            ret_ = enumGetBox(DockingIndicatorPosition_$type, EnumUtil.getEnumValue(DockingIndicatorPosition_$type, this.c.f(DockingIndicatorPosition_$type, ret_)));
            return EnumUtil.getEnumValue(DockingIndicatorPosition_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(DockingIndicatorPosition_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.c.v("position", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockingIndicator.prototype, "d", {
        get: function () {
            var ret_ = this.c.n("isRoot");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.v("isRoot", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockingIndicator.prototype, "g", {
        get: function () {
            var ret_ = this.c.n("direction");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.v("direction", value_);
        },
        enumerable: false,
        configurable: true
    });
    DockingIndicator.$t = markType(DockingIndicator, 'DockingIndicator');
    return DockingIndicator;
}(Base));
export { DockingIndicator };
